@@ -352,15 +352,18 @@ def fi_payment_reference_number(num: str):
     :return: Number plus checksum
     """
     assert isinstance(num, str)
-    num = STRIP_WHITESPACE.sub('', num)
-    num = re.sub(r'^0+', '', num)
-    assert len(num) >= 3
+    v = STRIP_WHITESPACE.sub('', num)
+    if digit_filter(v) != v:
+        raise ValidationError(_('Invalid payment reference: {}').format(num))
+    v = v.lstrip('0')
+    if len(v) < 3:
+        raise ValidationError(_('Invalid payment reference: {}').format(num))
     weights = [7, 3, 1]
     weighed_sum = 0
-    numlen = len(num)
-    for j in range(numlen):
-        weighed_sum += int(num[numlen - 1 - j]) * weights[j % 3]
-    return num + str((10 - (weighed_sum % 10)) % 10)
+    vlen = len(v)
+    for j in range(vlen):
+        weighed_sum += int(v[vlen - 1 - j]) * weights[j % 3]
+    return v + str((10 - (weighed_sum % 10)) % 10)
 
 
 def fi_payment_reference_validator(v: str):
